import type { Styler } from '../types/style.js';
import type { JsonTheme, Theme } from '../types/theme.js';
/**
 * Identity function for tokens that should not be styled (returns the input string as-is).
 * See [[Theme]] for an example.
 */
export declare const plain: Styler;
/**
 * The default theme. It is possible to override just individual keys.
 */
export declare const getDefaultTheme: () => Theme;
/**
    Converts a [[JsonTheme]] with string values to a [[Theme]] with formatter functions. Used by [[parse]].
*/
export declare function fromJson(json: JsonTheme): Theme;
/**
    Parses a JSON string into a [[Theme]] with formatter functions.

    ```ts
    import * as fs from 'node:fs';
    import { parse, highlight } from 'cli-highlighter';

    const json = fs.readFileSync('mytheme.json', 'utf8');
    const code = highlight('SELECT * FROM table', {theme: parse(json)});
    console.log(code);
    ```
*/
export declare function parse(json: string): Theme;
